pub struct Edge {
pub x0: f64,
pub top: f64,
pub x1: f64,
pub bottom: f64,
pub orientation: Orientation,
pub source: EdgeSource,
}Expand description
A line segment edge for table detection.
Edges are derived from Lines, Rects, and Curves and are used by the table detection algorithm to find cell boundaries.
Fields
x0: f64Left x coordinate.
top: f64Top y coordinate (distance from top of page).
x1: f64Right x coordinate.
bottom: f64Bottom y coordinate (distance from top of page).
orientation: OrientationEdge orientation.
source: EdgeSourceWhere this edge was derived from.