PageObject

Enum PageObject 

pub enum PageObject<'a> {
    Char(&'a Char),
    Line(&'a Line),
    Rect(&'a Rect),
    Curve(&'a Curve),
    Image(&'a Image),
}
An enum wrapping references to different page object types.

Used as the argument to filter predicates, allowing users to match on specific object types and inspect their properties.

Example

// Keep only characters with font "Helvetica" and all non-char objects
page.filter(|obj| match obj {
    PageObject::Char(c) => c.fontname == "Helvetica",
    _ => true,
});

Variants



Char(&'a Char)

A character object.



Line(&'a Line)

A line object.



Rect(&'a Rect)

A rectangle object.



Curve(&'a Curve)

A curve object.



Image(&'a Image)

An image object.