pub struct WordOptions {
pub x_tolerance: f64,
pub y_tolerance: f64,
pub keep_blank_chars: bool,
pub use_text_flow: bool,
pub text_direction: TextDirection,
}Expand description
Options for word extraction, matching pdfplumber defaults.
Fields
x_tolerance: f64Maximum horizontal distance between characters to group into a word.
y_tolerance: f64Maximum vertical distance between characters to group into a word.
keep_blank_chars: boolIf true, include blank/space characters in words instead of splitting on them.
use_text_flow: boolIf true, use the text flow order from the PDF content stream instead of spatial ordering.
text_direction: TextDirectionText direction for grouping characters.