pub struct TableSettings {Show 17 fields
pub strategy: Strategy,
pub snap_tolerance: f64,
pub snap_x_tolerance: f64,
pub snap_y_tolerance: f64,
pub join_tolerance: f64,
pub join_x_tolerance: f64,
pub join_y_tolerance: f64,
pub edge_min_length: f64,
pub min_words_vertical: usize,
pub min_words_horizontal: usize,
pub text_tolerance: f64,
pub text_x_tolerance: f64,
pub text_y_tolerance: f64,
pub intersection_tolerance: f64,
pub intersection_x_tolerance: f64,
pub intersection_y_tolerance: f64,
pub explicit_lines: Option<ExplicitLines>,
}Expand description
Configuration for table detection.
All tolerance values default to 3.0, matching Python pdfplumber defaults.
Fields
strategy: StrategyTable detection strategy.
snap_tolerance: f64General snap tolerance for aligning nearby edges.
snap_x_tolerance: f64Snap tolerance for horizontal alignment.
snap_y_tolerance: f64Snap tolerance for vertical alignment.
join_tolerance: f64General join tolerance for merging collinear edges.
join_x_tolerance: f64Join tolerance for horizontal edges.
join_y_tolerance: f64Join tolerance for vertical edges.
edge_min_length: f64Minimum edge length to consider for table detection.
min_words_vertical: usizeMinimum number of words sharing a vertical alignment for Stream strategy.
min_words_horizontal: usizeMinimum number of words sharing a horizontal alignment for Stream strategy.
text_tolerance: f64General text tolerance for assigning text to cells.
text_x_tolerance: f64Text tolerance along x-axis.
text_y_tolerance: f64Text tolerance along y-axis.
intersection_tolerance: f64General intersection tolerance for detecting edge crossings.
intersection_x_tolerance: f64Intersection tolerance along x-axis.
intersection_y_tolerance: f64Intersection tolerance along y-axis.
explicit_lines: Option<ExplicitLines>Optional explicit line coordinates for Explicit strategy.